Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterDNSOnnxInferenceServiceServer(s grpc.ServiceRegistrar, srv DNSOnnxInferenceServiceServer)
- func RegisterNodeAgentCryptoServiceServer(s grpc.ServiceRegistrar, srv NodeAgentCryptoServiceServer)
- func RegisterNodeAgentFeatureServiceServer(s grpc.ServiceRegistrar, srv NodeAgentFeatureServiceServer)
- type AgentKernelKeyringControllerCommandRequest
- func (*AgentKernelKeyringControllerCommandRequest) Descriptor() ([]byte, []int)deprecated
- func (x *AgentKernelKeyringControllerCommandRequest) GetCmd() []KERNEL_KEYRING_OPS_TYPES
- func (x *AgentKernelKeyringControllerCommandRequest) GetKeyTypes() []KERNEL_KEYRING_KEY_TYPES
- func (x *AgentKernelKeyringControllerCommandRequest) GetRingTypes() []KERNEL_KEYRING_TYPES
- func (*AgentKernelKeyringControllerCommandRequest) ProtoMessage()
- func (x *AgentKernelKeyringControllerCommandRequest) ProtoReflect() protoreflect.Message
- func (x *AgentKernelKeyringControllerCommandRequest) Reset()
- func (x *AgentKernelKeyringControllerCommandRequest) String() string
- type AgentKernelKeyringControllerCommandResponse
- func (*AgentKernelKeyringControllerCommandResponse) Descriptor() ([]byte, []int)deprecated
- func (x *AgentKernelKeyringControllerCommandResponse) GetResponse() []bool
- func (*AgentKernelKeyringControllerCommandResponse) ProtoMessage()
- func (x *AgentKernelKeyringControllerCommandResponse) ProtoReflect() protoreflect.Message
- func (x *AgentKernelKeyringControllerCommandResponse) Reset()
- func (x *AgentKernelKeyringControllerCommandResponse) String() string
- type DNSOnnxInferenceServiceClient
- type DNSOnnxInferenceServiceServer
- type DNS_MALICIOUS_FLAGS
- func (DNS_MALICIOUS_FLAGS) Descriptor() protoreflect.EnumDescriptor
- func (x DNS_MALICIOUS_FLAGS) Enum() *DNS_MALICIOUS_FLAGS
- func (DNS_MALICIOUS_FLAGS) EnumDescriptor() ([]byte, []int)deprecated
- func (x DNS_MALICIOUS_FLAGS) Number() protoreflect.EnumNumber
- func (x DNS_MALICIOUS_FLAGS) String() string
- func (DNS_MALICIOUS_FLAGS) Type() protoreflect.EnumType
- type DnsFeatures
- type DnsInferenceRequest
- func (*DnsInferenceRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DnsInferenceRequest) GetReshaped() []*DnsFeatures
- func (*DnsInferenceRequest) ProtoMessage()
- func (x *DnsInferenceRequest) ProtoReflect() protoreflect.Message
- func (x *DnsInferenceRequest) Reset()
- func (x *DnsInferenceRequest) String() string
- type DnsInferenceResponseEgress
- func (*DnsInferenceResponseEgress) Descriptor() ([]byte, []int)deprecated
- func (x *DnsInferenceResponseEgress) GetThreatType() bool
- func (*DnsInferenceResponseEgress) ProtoMessage()
- func (x *DnsInferenceResponseEgress) ProtoReflect() protoreflect.Message
- func (x *DnsInferenceResponseEgress) Reset()
- func (x *DnsInferenceResponseEgress) String() string
- type DnsInferenceResponseIngress
- func (*DnsInferenceResponseIngress) Descriptor() ([]byte, []int)deprecated
- func (x *DnsInferenceResponseIngress) GetProtocol() string
- func (x *DnsInferenceResponseIngress) GetThreatType() []bool
- func (*DnsInferenceResponseIngress) ProtoMessage()
- func (x *DnsInferenceResponseIngress) ProtoReflect() protoreflect.Message
- func (x *DnsInferenceResponseIngress) Reset()
- func (x *DnsInferenceResponseIngress) String() string
- type ElfSignatureRequest
- func (*ElfSignatureRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ElfSignatureRequest) GetEBPFProgramPayload() []byte
- func (*ElfSignatureRequest) ProtoMessage()
- func (x *ElfSignatureRequest) ProtoReflect() protoreflect.Message
- func (x *ElfSignatureRequest) Reset()
- func (x *ElfSignatureRequest) String() string
- type ElfSignatureResponse
- func (*ElfSignatureResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ElfSignatureResponse) GetPublicKey() []byte
- func (x *ElfSignatureResponse) GetSignature() []byte
- func (x *ElfSignatureResponse) GetSignatureHash() []byte
- func (*ElfSignatureResponse) ProtoMessage()
- func (x *ElfSignatureResponse) ProtoReflect() protoreflect.Message
- func (x *ElfSignatureResponse) Reset()
- func (x *ElfSignatureResponse) String() string
- type ExfilDomains
- func (*ExfilDomains) Descriptor() ([]byte, []int)deprecated
- func (x *ExfilDomains) GetDomain() string
- func (x *ExfilDomains) GetFeatureVectors() []uint32
- func (x *ExfilDomains) GetStatus() map[string]DNS_MALICIOUS_FLAGS
- func (x *ExfilDomains) GetTld() string
- func (x *ExfilDomains) GetTotalLength() int64
- func (*ExfilDomains) ProtoMessage()
- func (x *ExfilDomains) ProtoReflect() protoreflect.Message
- func (x *ExfilDomains) Reset()
- func (x *ExfilDomains) String() string
- type ExfilDomainsLength
- type ExfillSecurityLengthLimits
- func (*ExfillSecurityLengthLimits) Descriptor() ([]byte, []int)deprecated
- func (x *ExfillSecurityLengthLimits) GetDomainrangeExfilLimits() map[int32]int32
- func (*ExfillSecurityLengthLimits) ProtoMessage()
- func (x *ExfillSecurityLengthLimits) ProtoReflect() protoreflect.Message
- func (x *ExfillSecurityLengthLimits) Reset()
- func (x *ExfillSecurityLengthLimits) String() string
- type KERNEL_KEYRING_KEY_TYPES
- func (KERNEL_KEYRING_KEY_TYPES) Descriptor() protoreflect.EnumDescriptor
- func (x KERNEL_KEYRING_KEY_TYPES) Enum() *KERNEL_KEYRING_KEY_TYPES
- func (KERNEL_KEYRING_KEY_TYPES) EnumDescriptor() ([]byte, []int)deprecated
- func (x KERNEL_KEYRING_KEY_TYPES) Number() protoreflect.EnumNumber
- func (x KERNEL_KEYRING_KEY_TYPES) String() string
- func (KERNEL_KEYRING_KEY_TYPES) Type() protoreflect.EnumType
- type KERNEL_KEYRING_OPS_TYPES
- func (KERNEL_KEYRING_OPS_TYPES) Descriptor() protoreflect.EnumDescriptor
- func (x KERNEL_KEYRING_OPS_TYPES) Enum() *KERNEL_KEYRING_OPS_TYPES
- func (KERNEL_KEYRING_OPS_TYPES) EnumDescriptor() ([]byte, []int)deprecated
- func (x KERNEL_KEYRING_OPS_TYPES) Number() protoreflect.EnumNumber
- func (x KERNEL_KEYRING_OPS_TYPES) String() string
- func (KERNEL_KEYRING_OPS_TYPES) Type() protoreflect.EnumType
- type KERNEL_KEYRING_TYPES
- func (KERNEL_KEYRING_TYPES) Descriptor() protoreflect.EnumDescriptor
- func (x KERNEL_KEYRING_TYPES) Enum() *KERNEL_KEYRING_TYPES
- func (KERNEL_KEYRING_TYPES) EnumDescriptor() ([]byte, []int)deprecated
- func (x KERNEL_KEYRING_TYPES) Number() protoreflect.EnumNumber
- func (x KERNEL_KEYRING_TYPES) String() string
- func (KERNEL_KEYRING_TYPES) Type() protoreflect.EnumType
- type NodeAgentCryptoServiceClient
- type NodeAgentCryptoServiceServer
- type NodeAgentFeatureServiceClient
- type NodeAgentFeatureServiceServer
- type NodeAgentFeatureService_BidirstreamLimitsClient
- type NodeAgentFeatureService_BidirstreamLimitsServer
- type NodeAgentFeatureService_GetExfilDomainsClient
- type NodeAgentFeatureService_GetExfilDomainsServer
- type ServiceHeartBeatVersion
- func (*ServiceHeartBeatVersion) Descriptor() ([]byte, []int)deprecated
- func (x *ServiceHeartBeatVersion) GetVersion() string
- func (*ServiceHeartBeatVersion) ProtoMessage()
- func (x *ServiceHeartBeatVersion) ProtoReflect() protoreflect.Message
- func (x *ServiceHeartBeatVersion) Reset()
- func (x *ServiceHeartBeatVersion) String() string
- type UnimplementedDNSOnnxInferenceServiceServer
- func (UnimplementedDNSOnnxInferenceServiceServer) EgressInfer(context.Context, *DnsInferenceRequest) (*DnsInferenceResponseEgress, error)
- func (UnimplementedDNSOnnxInferenceServiceServer) IngressInfer(context.Context, *DnsInferenceRequest) (*DnsInferenceResponseIngress, error)
- func (UnimplementedDNSOnnxInferenceServiceServer) VersionInfo(context.Context, *emptypb.Empty) (*ServiceHeartBeatVersion, error)
- type UnimplementedNodeAgentCryptoServiceServer
- func (UnimplementedNodeAgentCryptoServiceServer) EBPFElfSignature(context.Context, *ElfSignatureRequest) (*ElfSignatureResponse, error)
- func (UnimplementedNodeAgentCryptoServiceServer) EBPFKeyringController(context.Context, *AgentKernelKeyringControllerCommandRequest) (*AgentKernelKeyringControllerCommandResponse, error)
- type UnimplementedNodeAgentFeatureServiceServer
- func (UnimplementedNodeAgentFeatureServiceServer) BidirstreamLimits(...) error
- func (UnimplementedNodeAgentFeatureServiceServer) GenExfilDomainsLength(context.Context, *ExfilDomains) (*ExfilDomainsLength, error)
- func (UnimplementedNodeAgentFeatureServiceServer) GetExfilDomains(*ExfilDomains, grpc.ServerStreamingServer[ExfilDomains]) error
- type UnsafeDNSOnnxInferenceServiceServer
- type UnsafeNodeAgentCryptoServiceServer
- type UnsafeNodeAgentFeatureServiceServer
Constants ¶
const ( NodeAgentFeatureService_GetExfilDomains_FullMethodName = "/exfil_kernel.NodeAgentFeatureService/GetExfilDomains" NodeAgentFeatureService_GenExfilDomainsLength_FullMethodName = "/exfil_kernel.NodeAgentFeatureService/GenExfilDomainsLength" NodeAgentFeatureService_BidirstreamLimits_FullMethodName = "/exfil_kernel.NodeAgentFeatureService/BidirstreamLimits" )
const ( NodeAgentCryptoService_EBPFElfSignature_FullMethodName = "/exfil_kernel.NodeAgentCryptoService/EBPFElfSignature" NodeAgentCryptoService_EBPFKeyringController_FullMethodName = "/exfil_kernel.NodeAgentCryptoService/EBPFKeyringController" )
const ( DNSOnnxInferenceService_IngressInfer_FullMethodName = "/exfil_kernel.DNSOnnxInferenceService/IngressInfer" DNSOnnxInferenceService_EgressInfer_FullMethodName = "/exfil_kernel.DNSOnnxInferenceService/EgressInfer" DNSOnnxInferenceService_VersionInfo_FullMethodName = "/exfil_kernel.DNSOnnxInferenceService/VersionInfo" )
Variables ¶
var ( DNS_MALICIOUS_FLAGS_name = map[int32]string{ 0: "MALICIOUS", 1: "SUSPICIOUS", } DNS_MALICIOUS_FLAGS_value = map[string]int32{ "MALICIOUS": 0, "SUSPICIOUS": 1, } )
Enum value maps for DNS_MALICIOUS_FLAGS.
var ( KERNEL_KEYRING_OPS_TYPES_name = map[int32]string{ 0: "KEYCTL_REVOKE", 1: "KEYCTL_REJECT", 2: "KEYCTL_CLEAR", } KERNEL_KEYRING_OPS_TYPES_value = map[string]int32{ "KEYCTL_REVOKE": 0, "KEYCTL_REJECT": 1, "KEYCTL_CLEAR": 2, } )
Enum value maps for KERNEL_KEYRING_OPS_TYPES.
var ( KERNEL_KEYRING_TYPES_name = map[int32]string{ 0: "USER", 1: "SESSION", 2: "PROCESS", } KERNEL_KEYRING_TYPES_value = map[string]int32{ "USER": 0, "SESSION": 1, "PROCESS": 2, } )
Enum value maps for KERNEL_KEYRING_TYPES.
var ( KERNEL_KEYRING_KEY_TYPES_name = map[int32]string{ 0: "K_USER", 1: "K_LOGONG", 2: "K_ASYMMETRIC", } KERNEL_KEYRING_KEY_TYPES_value = map[string]int32{ "K_USER": 0, "K_LOGONG": 1, "K_ASYMMETRIC": 2, } )
Enum value maps for KERNEL_KEYRING_KEY_TYPES.
var DNSOnnxInferenceService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "exfil_kernel.DNSOnnxInferenceService", HandlerType: (*DNSOnnxInferenceServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "IngressInfer", Handler: _DNSOnnxInferenceService_IngressInfer_Handler, }, { MethodName: "EgressInfer", Handler: _DNSOnnxInferenceService_EgressInfer_Handler, }, { MethodName: "VersionInfo", Handler: _DNSOnnxInferenceService_VersionInfo_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "exfil_sec_inference.proto", }
DNSOnnxInferenceService_ServiceDesc is the grpc.ServiceDesc for DNSOnnxInferenceService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_exfil_sec_controller_proto protoreflect.FileDescriptor
var File_exfil_sec_inference_proto protoreflect.FileDescriptor
var NodeAgentCryptoService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "exfil_kernel.NodeAgentCryptoService", HandlerType: (*NodeAgentCryptoServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "EBPFElfSignature", Handler: _NodeAgentCryptoService_EBPFElfSignature_Handler, }, { MethodName: "EBPFKeyringController", Handler: _NodeAgentCryptoService_EBPFKeyringController_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "exfil_sec_controller.proto", }
NodeAgentCryptoService_ServiceDesc is the grpc.ServiceDesc for NodeAgentCryptoService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var NodeAgentFeatureService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "exfil_kernel.NodeAgentFeatureService", HandlerType: (*NodeAgentFeatureServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GenExfilDomainsLength", Handler: _NodeAgentFeatureService_GenExfilDomainsLength_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "GetExfilDomains", Handler: _NodeAgentFeatureService_GetExfilDomains_Handler, ServerStreams: true, }, { StreamName: "BidirstreamLimits", Handler: _NodeAgentFeatureService_BidirstreamLimits_Handler, ServerStreams: true, ClientStreams: true, }, }, Metadata: "exfil_sec_controller.proto", }
NodeAgentFeatureService_ServiceDesc is the grpc.ServiceDesc for NodeAgentFeatureService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterDNSOnnxInferenceServiceServer ¶
func RegisterDNSOnnxInferenceServiceServer(s grpc.ServiceRegistrar, srv DNSOnnxInferenceServiceServer)
func RegisterNodeAgentCryptoServiceServer ¶
func RegisterNodeAgentCryptoServiceServer(s grpc.ServiceRegistrar, srv NodeAgentCryptoServiceServer)
func RegisterNodeAgentFeatureServiceServer ¶
func RegisterNodeAgentFeatureServiceServer(s grpc.ServiceRegistrar, srv NodeAgentFeatureServiceServer)
Types ¶
type AgentKernelKeyringControllerCommandRequest ¶
type AgentKernelKeyringControllerCommandRequest struct {
Cmd []KERNEL_KEYRING_OPS_TYPES `protobuf:"varint,1,rep,packed,name=cmd,proto3,enum=exfil_kernel.KERNEL_KEYRING_OPS_TYPES" json:"cmd,omitempty"`
RingTypes []KERNEL_KEYRING_TYPES `protobuf:"varint,2,rep,packed,name=ringTypes,proto3,enum=exfil_kernel.KERNEL_KEYRING_TYPES" json:"ringTypes,omitempty"`
KeyTypes []KERNEL_KEYRING_KEY_TYPES `protobuf:"varint,3,rep,packed,name=keyTypes,proto3,enum=exfil_kernel.KERNEL_KEYRING_KEY_TYPES" json:"keyTypes,omitempty"`
// contains filtered or unexported fields
}
func (*AgentKernelKeyringControllerCommandRequest) Descriptor
deprecated
func (*AgentKernelKeyringControllerCommandRequest) Descriptor() ([]byte, []int)
Deprecated: Use AgentKernelKeyringControllerCommandRequest.ProtoReflect.Descriptor instead.
func (*AgentKernelKeyringControllerCommandRequest) GetCmd ¶
func (x *AgentKernelKeyringControllerCommandRequest) GetCmd() []KERNEL_KEYRING_OPS_TYPES
func (*AgentKernelKeyringControllerCommandRequest) GetKeyTypes ¶
func (x *AgentKernelKeyringControllerCommandRequest) GetKeyTypes() []KERNEL_KEYRING_KEY_TYPES
func (*AgentKernelKeyringControllerCommandRequest) GetRingTypes ¶
func (x *AgentKernelKeyringControllerCommandRequest) GetRingTypes() []KERNEL_KEYRING_TYPES
func (*AgentKernelKeyringControllerCommandRequest) ProtoMessage ¶
func (*AgentKernelKeyringControllerCommandRequest) ProtoMessage()
func (*AgentKernelKeyringControllerCommandRequest) ProtoReflect ¶
func (x *AgentKernelKeyringControllerCommandRequest) ProtoReflect() protoreflect.Message
func (*AgentKernelKeyringControllerCommandRequest) Reset ¶
func (x *AgentKernelKeyringControllerCommandRequest) Reset()
func (*AgentKernelKeyringControllerCommandRequest) String ¶
func (x *AgentKernelKeyringControllerCommandRequest) String() string
type AgentKernelKeyringControllerCommandResponse ¶
type AgentKernelKeyringControllerCommandResponse struct {
Response []bool `protobuf:"varint,1,rep,packed,name=response,proto3" json:"response,omitempty"`
// contains filtered or unexported fields
}
func (*AgentKernelKeyringControllerCommandResponse) Descriptor
deprecated
func (*AgentKernelKeyringControllerCommandResponse) Descriptor() ([]byte, []int)
Deprecated: Use AgentKernelKeyringControllerCommandResponse.ProtoReflect.Descriptor instead.
func (*AgentKernelKeyringControllerCommandResponse) GetResponse ¶
func (x *AgentKernelKeyringControllerCommandResponse) GetResponse() []bool
func (*AgentKernelKeyringControllerCommandResponse) ProtoMessage ¶
func (*AgentKernelKeyringControllerCommandResponse) ProtoMessage()
func (*AgentKernelKeyringControllerCommandResponse) ProtoReflect ¶
func (x *AgentKernelKeyringControllerCommandResponse) ProtoReflect() protoreflect.Message
func (*AgentKernelKeyringControllerCommandResponse) Reset ¶
func (x *AgentKernelKeyringControllerCommandResponse) Reset()
func (*AgentKernelKeyringControllerCommandResponse) String ¶
func (x *AgentKernelKeyringControllerCommandResponse) String() string
type DNSOnnxInferenceServiceClient ¶
type DNSOnnxInferenceServiceClient interface {
IngressInfer(ctx context.Context, in *DnsInferenceRequest, opts ...grpc.CallOption) (*DnsInferenceResponseIngress, error)
EgressInfer(ctx context.Context, in *DnsInferenceRequest, opts ...grpc.CallOption) (*DnsInferenceResponseEgress, error)
VersionInfo(ctx context.Context, in *emptypb.Empty, opts ...grpc.CallOption) (*ServiceHeartBeatVersion, error)
}
DNSOnnxInferenceServiceClient is the client API for DNSOnnxInferenceService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewDNSOnnxInferenceServiceClient ¶
func NewDNSOnnxInferenceServiceClient(cc grpc.ClientConnInterface) DNSOnnxInferenceServiceClient
type DNSOnnxInferenceServiceServer ¶
type DNSOnnxInferenceServiceServer interface {
IngressInfer(context.Context, *DnsInferenceRequest) (*DnsInferenceResponseIngress, error)
EgressInfer(context.Context, *DnsInferenceRequest) (*DnsInferenceResponseEgress, error)
VersionInfo(context.Context, *emptypb.Empty) (*ServiceHeartBeatVersion, error)
}
DNSOnnxInferenceServiceServer is the server API for DNSOnnxInferenceService service. All implementations should embed UnimplementedDNSOnnxInferenceServiceServer for forward compatibility.
type DNS_MALICIOUS_FLAGS ¶
type DNS_MALICIOUS_FLAGS int32
const ( DNS_MALICIOUS_FLAGS_MALICIOUS DNS_MALICIOUS_FLAGS = 0 DNS_MALICIOUS_FLAGS_SUSPICIOUS DNS_MALICIOUS_FLAGS = 1 )
func (DNS_MALICIOUS_FLAGS) Descriptor ¶
func (DNS_MALICIOUS_FLAGS) Descriptor() protoreflect.EnumDescriptor
func (DNS_MALICIOUS_FLAGS) Enum ¶
func (x DNS_MALICIOUS_FLAGS) Enum() *DNS_MALICIOUS_FLAGS
func (DNS_MALICIOUS_FLAGS) EnumDescriptor
deprecated
func (DNS_MALICIOUS_FLAGS) EnumDescriptor() ([]byte, []int)
Deprecated: Use DNS_MALICIOUS_FLAGS.Descriptor instead.
func (DNS_MALICIOUS_FLAGS) Number ¶
func (x DNS_MALICIOUS_FLAGS) Number() protoreflect.EnumNumber
func (DNS_MALICIOUS_FLAGS) String ¶
func (x DNS_MALICIOUS_FLAGS) String() string
func (DNS_MALICIOUS_FLAGS) Type ¶
func (DNS_MALICIOUS_FLAGS) Type() protoreflect.EnumType
type DnsFeatures ¶
type DnsFeatures struct {
Features []float32 `protobuf:"fixed32,1,rep,packed,name=features,proto3" json:"features,omitempty"`
// contains filtered or unexported fields
}
func (*DnsFeatures) Descriptor
deprecated
func (*DnsFeatures) Descriptor() ([]byte, []int)
Deprecated: Use DnsFeatures.ProtoReflect.Descriptor instead.
func (*DnsFeatures) GetFeatures ¶
func (x *DnsFeatures) GetFeatures() []float32
func (*DnsFeatures) ProtoMessage ¶
func (*DnsFeatures) ProtoMessage()
func (*DnsFeatures) ProtoReflect ¶
func (x *DnsFeatures) ProtoReflect() protoreflect.Message
func (*DnsFeatures) Reset ¶
func (x *DnsFeatures) Reset()
func (*DnsFeatures) String ¶
func (x *DnsFeatures) String() string
type DnsInferenceRequest ¶
type DnsInferenceRequest struct {
Reshaped []*DnsFeatures `protobuf:"bytes,1,rep,name=reshaped,proto3" json:"reshaped,omitempty"` // features over rpc are reshaped adhere to shape for inference request
// contains filtered or unexported fields
}
func (*DnsInferenceRequest) Descriptor
deprecated
func (*DnsInferenceRequest) Descriptor() ([]byte, []int)
Deprecated: Use DnsInferenceRequest.ProtoReflect.Descriptor instead.
func (*DnsInferenceRequest) GetReshaped ¶
func (x *DnsInferenceRequest) GetReshaped() []*DnsFeatures
func (*DnsInferenceRequest) ProtoMessage ¶
func (*DnsInferenceRequest) ProtoMessage()
func (*DnsInferenceRequest) ProtoReflect ¶
func (x *DnsInferenceRequest) ProtoReflect() protoreflect.Message
func (*DnsInferenceRequest) Reset ¶
func (x *DnsInferenceRequest) Reset()
func (*DnsInferenceRequest) String ¶
func (x *DnsInferenceRequest) String() string
type DnsInferenceResponseEgress ¶
type DnsInferenceResponseEgress struct {
ThreatType bool `protobuf:"varint,1,opt,name=threatType,proto3" json:"threatType,omitempty"`
// contains filtered or unexported fields
}
func (*DnsInferenceResponseEgress) Descriptor
deprecated
func (*DnsInferenceResponseEgress) Descriptor() ([]byte, []int)
Deprecated: Use DnsInferenceResponseEgress.ProtoReflect.Descriptor instead.
func (*DnsInferenceResponseEgress) GetThreatType ¶
func (x *DnsInferenceResponseEgress) GetThreatType() bool
func (*DnsInferenceResponseEgress) ProtoMessage ¶
func (*DnsInferenceResponseEgress) ProtoMessage()
func (*DnsInferenceResponseEgress) ProtoReflect ¶
func (x *DnsInferenceResponseEgress) ProtoReflect() protoreflect.Message
func (*DnsInferenceResponseEgress) Reset ¶
func (x *DnsInferenceResponseEgress) Reset()
func (*DnsInferenceResponseEgress) String ¶
func (x *DnsInferenceResponseEgress) String() string
type DnsInferenceResponseIngress ¶
type DnsInferenceResponseIngress struct {
ThreatType []bool `protobuf:"varint,1,rep,packed,name=threatType,proto3" json:"threatType,omitempty"`
Protocol string `protobuf:"bytes,2,opt,name=protocol,proto3" json:"protocol,omitempty"`
// contains filtered or unexported fields
}
func (*DnsInferenceResponseIngress) Descriptor
deprecated
func (*DnsInferenceResponseIngress) Descriptor() ([]byte, []int)
Deprecated: Use DnsInferenceResponseIngress.ProtoReflect.Descriptor instead.
func (*DnsInferenceResponseIngress) GetProtocol ¶
func (x *DnsInferenceResponseIngress) GetProtocol() string
func (*DnsInferenceResponseIngress) GetThreatType ¶
func (x *DnsInferenceResponseIngress) GetThreatType() []bool
func (*DnsInferenceResponseIngress) ProtoMessage ¶
func (*DnsInferenceResponseIngress) ProtoMessage()
func (*DnsInferenceResponseIngress) ProtoReflect ¶
func (x *DnsInferenceResponseIngress) ProtoReflect() protoreflect.Message
func (*DnsInferenceResponseIngress) Reset ¶
func (x *DnsInferenceResponseIngress) Reset()
func (*DnsInferenceResponseIngress) String ¶
func (x *DnsInferenceResponseIngress) String() string
type ElfSignatureRequest ¶
type ElfSignatureRequest struct {
EBPFProgramPayload []byte `protobuf:"bytes,1,opt,name=eBPFProgramPayload,proto3" json:"eBPFProgramPayload,omitempty"`
// contains filtered or unexported fields
}
func (*ElfSignatureRequest) Descriptor
deprecated
func (*ElfSignatureRequest) Descriptor() ([]byte, []int)
Deprecated: Use ElfSignatureRequest.ProtoReflect.Descriptor instead.
func (*ElfSignatureRequest) GetEBPFProgramPayload ¶
func (x *ElfSignatureRequest) GetEBPFProgramPayload() []byte
func (*ElfSignatureRequest) ProtoMessage ¶
func (*ElfSignatureRequest) ProtoMessage()
func (*ElfSignatureRequest) ProtoReflect ¶
func (x *ElfSignatureRequest) ProtoReflect() protoreflect.Message
func (*ElfSignatureRequest) Reset ¶
func (x *ElfSignatureRequest) Reset()
func (*ElfSignatureRequest) String ¶
func (x *ElfSignatureRequest) String() string
type ElfSignatureResponse ¶
type ElfSignatureResponse struct {
Signature []byte `protobuf:"bytes,1,opt,name=signature,proto3" json:"signature,omitempty"`
PublicKey []byte `protobuf:"bytes,2,opt,name=publicKey,proto3" json:"publicKey,omitempty"`
SignatureHash []byte `protobuf:"bytes,3,opt,name=signatureHash,proto3" json:"signatureHash,omitempty"`
// contains filtered or unexported fields
}
func (*ElfSignatureResponse) Descriptor
deprecated
func (*ElfSignatureResponse) Descriptor() ([]byte, []int)
Deprecated: Use ElfSignatureResponse.ProtoReflect.Descriptor instead.
func (*ElfSignatureResponse) GetPublicKey ¶
func (x *ElfSignatureResponse) GetPublicKey() []byte
func (*ElfSignatureResponse) GetSignature ¶
func (x *ElfSignatureResponse) GetSignature() []byte
func (*ElfSignatureResponse) GetSignatureHash ¶
func (x *ElfSignatureResponse) GetSignatureHash() []byte
func (*ElfSignatureResponse) ProtoMessage ¶
func (*ElfSignatureResponse) ProtoMessage()
func (*ElfSignatureResponse) ProtoReflect ¶
func (x *ElfSignatureResponse) ProtoReflect() protoreflect.Message
func (*ElfSignatureResponse) Reset ¶
func (x *ElfSignatureResponse) Reset()
func (*ElfSignatureResponse) String ¶
func (x *ElfSignatureResponse) String() string
type ExfilDomains ¶
type ExfilDomains struct {
Domain string `protobuf:"bytes,1,opt,name=domain,proto3" json:"domain,omitempty"`
Tld string `protobuf:"bytes,2,opt,name=tld,proto3" json:"tld,omitempty"`
TotalLength int64 `protobuf:"varint,3,opt,name=totalLength,proto3" json:"totalLength,omitempty"`
FeatureVectors []uint32 `protobuf:"varint,4,rep,packed,name=featureVectors,proto3" json:"featureVectors,omitempty"`
Status map[string]DNS_MALICIOUS_FLAGS `` /* 178-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*ExfilDomains) Descriptor
deprecated
func (*ExfilDomains) Descriptor() ([]byte, []int)
Deprecated: Use ExfilDomains.ProtoReflect.Descriptor instead.
func (*ExfilDomains) GetDomain ¶
func (x *ExfilDomains) GetDomain() string
func (*ExfilDomains) GetFeatureVectors ¶
func (x *ExfilDomains) GetFeatureVectors() []uint32
func (*ExfilDomains) GetStatus ¶
func (x *ExfilDomains) GetStatus() map[string]DNS_MALICIOUS_FLAGS
func (*ExfilDomains) GetTld ¶
func (x *ExfilDomains) GetTld() string
func (*ExfilDomains) GetTotalLength ¶
func (x *ExfilDomains) GetTotalLength() int64
func (*ExfilDomains) ProtoMessage ¶
func (*ExfilDomains) ProtoMessage()
func (*ExfilDomains) ProtoReflect ¶
func (x *ExfilDomains) ProtoReflect() protoreflect.Message
func (*ExfilDomains) Reset ¶
func (x *ExfilDomains) Reset()
func (*ExfilDomains) String ¶
func (x *ExfilDomains) String() string
type ExfilDomainsLength ¶
type ExfilDomainsLength struct {
Len int64 `protobuf:"varint,1,opt,name=len,proto3" json:"len,omitempty"`
// contains filtered or unexported fields
}
func (*ExfilDomainsLength) Descriptor
deprecated
func (*ExfilDomainsLength) Descriptor() ([]byte, []int)
Deprecated: Use ExfilDomainsLength.ProtoReflect.Descriptor instead.
func (*ExfilDomainsLength) GetLen ¶
func (x *ExfilDomainsLength) GetLen() int64
func (*ExfilDomainsLength) ProtoMessage ¶
func (*ExfilDomainsLength) ProtoMessage()
func (*ExfilDomainsLength) ProtoReflect ¶
func (x *ExfilDomainsLength) ProtoReflect() protoreflect.Message
func (*ExfilDomainsLength) Reset ¶
func (x *ExfilDomainsLength) Reset()
func (*ExfilDomainsLength) String ¶
func (x *ExfilDomainsLength) String() string
type ExfillSecurityLengthLimits ¶
type ExfillSecurityLengthLimits struct {
DomainrangeExfilLimits map[int32]int32 `` /* 173-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*ExfillSecurityLengthLimits) Descriptor
deprecated
func (*ExfillSecurityLengthLimits) Descriptor() ([]byte, []int)
Deprecated: Use ExfillSecurityLengthLimits.ProtoReflect.Descriptor instead.
func (*ExfillSecurityLengthLimits) GetDomainrangeExfilLimits ¶
func (x *ExfillSecurityLengthLimits) GetDomainrangeExfilLimits() map[int32]int32
func (*ExfillSecurityLengthLimits) ProtoMessage ¶
func (*ExfillSecurityLengthLimits) ProtoMessage()
func (*ExfillSecurityLengthLimits) ProtoReflect ¶
func (x *ExfillSecurityLengthLimits) ProtoReflect() protoreflect.Message
func (*ExfillSecurityLengthLimits) Reset ¶
func (x *ExfillSecurityLengthLimits) Reset()
func (*ExfillSecurityLengthLimits) String ¶
func (x *ExfillSecurityLengthLimits) String() string
type KERNEL_KEYRING_KEY_TYPES ¶
type KERNEL_KEYRING_KEY_TYPES int32
const ( KERNEL_KEYRING_KEY_TYPES_K_USER KERNEL_KEYRING_KEY_TYPES = 0 KERNEL_KEYRING_KEY_TYPES_K_LOGONG KERNEL_KEYRING_KEY_TYPES = 1 KERNEL_KEYRING_KEY_TYPES_K_ASYMMETRIC KERNEL_KEYRING_KEY_TYPES = 2 )
func (KERNEL_KEYRING_KEY_TYPES) Descriptor ¶
func (KERNEL_KEYRING_KEY_TYPES) Descriptor() protoreflect.EnumDescriptor
func (KERNEL_KEYRING_KEY_TYPES) Enum ¶
func (x KERNEL_KEYRING_KEY_TYPES) Enum() *KERNEL_KEYRING_KEY_TYPES
func (KERNEL_KEYRING_KEY_TYPES) EnumDescriptor
deprecated
func (KERNEL_KEYRING_KEY_TYPES) EnumDescriptor() ([]byte, []int)
Deprecated: Use KERNEL_KEYRING_KEY_TYPES.Descriptor instead.
func (KERNEL_KEYRING_KEY_TYPES) Number ¶
func (x KERNEL_KEYRING_KEY_TYPES) Number() protoreflect.EnumNumber
func (KERNEL_KEYRING_KEY_TYPES) String ¶
func (x KERNEL_KEYRING_KEY_TYPES) String() string
func (KERNEL_KEYRING_KEY_TYPES) Type ¶
func (KERNEL_KEYRING_KEY_TYPES) Type() protoreflect.EnumType
type KERNEL_KEYRING_OPS_TYPES ¶
type KERNEL_KEYRING_OPS_TYPES int32
const ( KERNEL_KEYRING_OPS_TYPES_KEYCTL_REVOKE KERNEL_KEYRING_OPS_TYPES = 0 KERNEL_KEYRING_OPS_TYPES_KEYCTL_REJECT KERNEL_KEYRING_OPS_TYPES = 1 KERNEL_KEYRING_OPS_TYPES_KEYCTL_CLEAR KERNEL_KEYRING_OPS_TYPES = 2 )
func (KERNEL_KEYRING_OPS_TYPES) Descriptor ¶
func (KERNEL_KEYRING_OPS_TYPES) Descriptor() protoreflect.EnumDescriptor
func (KERNEL_KEYRING_OPS_TYPES) Enum ¶
func (x KERNEL_KEYRING_OPS_TYPES) Enum() *KERNEL_KEYRING_OPS_TYPES
func (KERNEL_KEYRING_OPS_TYPES) EnumDescriptor
deprecated
func (KERNEL_KEYRING_OPS_TYPES) EnumDescriptor() ([]byte, []int)
Deprecated: Use KERNEL_KEYRING_OPS_TYPES.Descriptor instead.
func (KERNEL_KEYRING_OPS_TYPES) Number ¶
func (x KERNEL_KEYRING_OPS_TYPES) Number() protoreflect.EnumNumber
func (KERNEL_KEYRING_OPS_TYPES) String ¶
func (x KERNEL_KEYRING_OPS_TYPES) String() string
func (KERNEL_KEYRING_OPS_TYPES) Type ¶
func (KERNEL_KEYRING_OPS_TYPES) Type() protoreflect.EnumType
type KERNEL_KEYRING_TYPES ¶
type KERNEL_KEYRING_TYPES int32
const ( KERNEL_KEYRING_TYPES_USER KERNEL_KEYRING_TYPES = 0 KERNEL_KEYRING_TYPES_SESSION KERNEL_KEYRING_TYPES = 1 KERNEL_KEYRING_TYPES_PROCESS KERNEL_KEYRING_TYPES = 2 )
func (KERNEL_KEYRING_TYPES) Descriptor ¶
func (KERNEL_KEYRING_TYPES) Descriptor() protoreflect.EnumDescriptor
func (KERNEL_KEYRING_TYPES) Enum ¶
func (x KERNEL_KEYRING_TYPES) Enum() *KERNEL_KEYRING_TYPES
func (KERNEL_KEYRING_TYPES) EnumDescriptor
deprecated
func (KERNEL_KEYRING_TYPES) EnumDescriptor() ([]byte, []int)
Deprecated: Use KERNEL_KEYRING_TYPES.Descriptor instead.
func (KERNEL_KEYRING_TYPES) Number ¶
func (x KERNEL_KEYRING_TYPES) Number() protoreflect.EnumNumber
func (KERNEL_KEYRING_TYPES) String ¶
func (x KERNEL_KEYRING_TYPES) String() string
func (KERNEL_KEYRING_TYPES) Type ¶
func (KERNEL_KEYRING_TYPES) Type() protoreflect.EnumType
type NodeAgentCryptoServiceClient ¶
type NodeAgentCryptoServiceClient interface {
EBPFElfSignature(ctx context.Context, in *ElfSignatureRequest, opts ...grpc.CallOption) (*ElfSignatureResponse, error)
EBPFKeyringController(ctx context.Context, in *AgentKernelKeyringControllerCommandRequest, opts ...grpc.CallOption) (*AgentKernelKeyringControllerCommandResponse, error)
}
NodeAgentCryptoServiceClient is the client API for NodeAgentCryptoService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewNodeAgentCryptoServiceClient ¶
func NewNodeAgentCryptoServiceClient(cc grpc.ClientConnInterface) NodeAgentCryptoServiceClient
type NodeAgentCryptoServiceServer ¶
type NodeAgentCryptoServiceServer interface {
EBPFElfSignature(context.Context, *ElfSignatureRequest) (*ElfSignatureResponse, error)
EBPFKeyringController(context.Context, *AgentKernelKeyringControllerCommandRequest) (*AgentKernelKeyringControllerCommandResponse, error)
}
NodeAgentCryptoServiceServer is the server API for NodeAgentCryptoService service. All implementations should embed UnimplementedNodeAgentCryptoServiceServer for forward compatibility.
type NodeAgentFeatureServiceClient ¶
type NodeAgentFeatureServiceClient interface {
GetExfilDomains(ctx context.Context, in *ExfilDomains, opts ...grpc.CallOption) (grpc.ServerStreamingClient[ExfilDomains], error)
GenExfilDomainsLength(ctx context.Context, in *ExfilDomains, opts ...grpc.CallOption) (*ExfilDomainsLength, error)
BidirstreamLimits(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[ExfillSecurityLengthLimits, ExfillSecurityLengthLimits], error)
}
NodeAgentFeatureServiceClient is the client API for NodeAgentFeatureService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewNodeAgentFeatureServiceClient ¶
func NewNodeAgentFeatureServiceClient(cc grpc.ClientConnInterface) NodeAgentFeatureServiceClient
type NodeAgentFeatureServiceServer ¶
type NodeAgentFeatureServiceServer interface {
GetExfilDomains(*ExfilDomains, grpc.ServerStreamingServer[ExfilDomains]) error
GenExfilDomainsLength(context.Context, *ExfilDomains) (*ExfilDomainsLength, error)
BidirstreamLimits(grpc.BidiStreamingServer[ExfillSecurityLengthLimits, ExfillSecurityLengthLimits]) error
}
NodeAgentFeatureServiceServer is the server API for NodeAgentFeatureService service. All implementations should embed UnimplementedNodeAgentFeatureServiceServer for forward compatibility.
type NodeAgentFeatureService_BidirstreamLimitsClient ¶
type NodeAgentFeatureService_BidirstreamLimitsClient = grpc.BidiStreamingClient[ExfillSecurityLengthLimits, ExfillSecurityLengthLimits]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type NodeAgentFeatureService_BidirstreamLimitsServer ¶
type NodeAgentFeatureService_BidirstreamLimitsServer = grpc.BidiStreamingServer[ExfillSecurityLengthLimits, ExfillSecurityLengthLimits]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type NodeAgentFeatureService_GetExfilDomainsClient ¶
type NodeAgentFeatureService_GetExfilDomainsClient = grpc.ServerStreamingClient[ExfilDomains]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type NodeAgentFeatureService_GetExfilDomainsServer ¶
type NodeAgentFeatureService_GetExfilDomainsServer = grpc.ServerStreamingServer[ExfilDomains]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ServiceHeartBeatVersion ¶
type ServiceHeartBeatVersion struct {
Version string `protobuf:"bytes,1,opt,name=version,proto3" json:"version,omitempty"`
// contains filtered or unexported fields
}
func (*ServiceHeartBeatVersion) Descriptor
deprecated
func (*ServiceHeartBeatVersion) Descriptor() ([]byte, []int)
Deprecated: Use ServiceHeartBeatVersion.ProtoReflect.Descriptor instead.
func (*ServiceHeartBeatVersion) GetVersion ¶
func (x *ServiceHeartBeatVersion) GetVersion() string
func (*ServiceHeartBeatVersion) ProtoMessage ¶
func (*ServiceHeartBeatVersion) ProtoMessage()
func (*ServiceHeartBeatVersion) ProtoReflect ¶
func (x *ServiceHeartBeatVersion) ProtoReflect() protoreflect.Message
func (*ServiceHeartBeatVersion) Reset ¶
func (x *ServiceHeartBeatVersion) Reset()
func (*ServiceHeartBeatVersion) String ¶
func (x *ServiceHeartBeatVersion) String() string
type UnimplementedDNSOnnxInferenceServiceServer ¶
type UnimplementedDNSOnnxInferenceServiceServer struct{}
UnimplementedDNSOnnxInferenceServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedDNSOnnxInferenceServiceServer) EgressInfer ¶
func (UnimplementedDNSOnnxInferenceServiceServer) EgressInfer(context.Context, *DnsInferenceRequest) (*DnsInferenceResponseEgress, error)
func (UnimplementedDNSOnnxInferenceServiceServer) IngressInfer ¶
func (UnimplementedDNSOnnxInferenceServiceServer) IngressInfer(context.Context, *DnsInferenceRequest) (*DnsInferenceResponseIngress, error)
func (UnimplementedDNSOnnxInferenceServiceServer) VersionInfo ¶
func (UnimplementedDNSOnnxInferenceServiceServer) VersionInfo(context.Context, *emptypb.Empty) (*ServiceHeartBeatVersion, error)
type UnimplementedNodeAgentCryptoServiceServer ¶
type UnimplementedNodeAgentCryptoServiceServer struct{}
UnimplementedNodeAgentCryptoServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedNodeAgentCryptoServiceServer) EBPFElfSignature ¶
func (UnimplementedNodeAgentCryptoServiceServer) EBPFElfSignature(context.Context, *ElfSignatureRequest) (*ElfSignatureResponse, error)
func (UnimplementedNodeAgentCryptoServiceServer) EBPFKeyringController ¶
func (UnimplementedNodeAgentCryptoServiceServer) EBPFKeyringController(context.Context, *AgentKernelKeyringControllerCommandRequest) (*AgentKernelKeyringControllerCommandResponse, error)
type UnimplementedNodeAgentFeatureServiceServer ¶
type UnimplementedNodeAgentFeatureServiceServer struct{}
UnimplementedNodeAgentFeatureServiceServer should be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedNodeAgentFeatureServiceServer) BidirstreamLimits ¶
func (UnimplementedNodeAgentFeatureServiceServer) BidirstreamLimits(grpc.BidiStreamingServer[ExfillSecurityLengthLimits, ExfillSecurityLengthLimits]) error
func (UnimplementedNodeAgentFeatureServiceServer) GenExfilDomainsLength ¶
func (UnimplementedNodeAgentFeatureServiceServer) GenExfilDomainsLength(context.Context, *ExfilDomains) (*ExfilDomainsLength, error)
func (UnimplementedNodeAgentFeatureServiceServer) GetExfilDomains ¶
func (UnimplementedNodeAgentFeatureServiceServer) GetExfilDomains(*ExfilDomains, grpc.ServerStreamingServer[ExfilDomains]) error
type UnsafeDNSOnnxInferenceServiceServer ¶
type UnsafeDNSOnnxInferenceServiceServer interface {
// contains filtered or unexported methods
}
UnsafeDNSOnnxInferenceServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DNSOnnxInferenceServiceServer will result in compilation errors.
type UnsafeNodeAgentCryptoServiceServer ¶
type UnsafeNodeAgentCryptoServiceServer interface {
// contains filtered or unexported methods
}
UnsafeNodeAgentCryptoServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to NodeAgentCryptoServiceServer will result in compilation errors.
type UnsafeNodeAgentFeatureServiceServer ¶
type UnsafeNodeAgentFeatureServiceServer interface {
// contains filtered or unexported methods
}
UnsafeNodeAgentFeatureServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to NodeAgentFeatureServiceServer will result in compilation errors.